@@ -7,6 +7,9 @@ router.APIRootView = views.UCBoxPluginRootView
 
 router.register(r'numbers', views.NumberViewSet)
 router.register(r'trunks', views.TrunkViewSet)
+router.register(r"clusters", views.ClusterViewSet)
+router.register(r"devicepools", views.DevicePoolViewSet)
+
 
 app_name = "ucbox_plugin-api"
 urlpatterns = router.urls
