@@ -1,6 +1,6 @@
 from rest_framework.routers import APIRootView
 from .. import filters
-from ..models import Number, Trunk
+from ..models import Number, Trunk, Cluster, DevicePool
 from netbox.api.views import ModelViewSet
 from . import serializers
 
@@ -21,4 +21,14 @@ class NumberViewSet(ModelViewSet):
 class TrunkViewSet(ModelViewSet):
     queryset = Trunk.objects.prefetch_related('tenant', 'region', 'tags')
     serializer_class = serializers.TrunkSerializer
-    filterset_class = filters.TrunkFilterSet
\ No newline at end of file
+    filterset_class = filters.TrunkFilterSet
+
+class ClusterViewSet(ModelViewSet):
+    queryset = Cluster.objects.prefetch_related('tenant', 'tags')
+    serializer_class = serializers.ClusterSerializer
+    filterset_class = filters.ClusterFilterSet
+
+class DevicePoolViewSet(ModelViewSet):
+    queryset = DevicePool.objects.prefetch_related('tenant', 'region', 'tags')
+    serializer_class = serializers.DevicePoolSerializer
+    filterset_class = filters.DevicePoolFilterSet
\ No newline at end of file
