@@ -3,7 +3,7 @@ from django.db.models import Q
 from circuits.models import Provider
 from dcim.models import Region
 from tenancy.models import Tenant
-from .models import Number, Trunk
+from .models import Number, Trunk, Cluster, DevicePool
 from packaging import version
 from django.conf import settings
 
@@ -110,3 +110,73 @@ class TrunkFilterSet(BaseFilterSet):
         return queryset.filter(
             Q(trunk__icontains=value)
         )
+
+
+class ClusterFilterSet(BaseFilterSet):
+
+    q = django_filters.CharFilter(
+        method='search',
+        label='Search',
+    )
+    cluster = django_filters.ModelMultipleChoiceFilter(
+        field_name='cluster',
+        queryset=Cluster.objects.all(),
+        to_field_name='cluster',
+        label='cluster',
+    )
+    tenant = django_filters.ModelMultipleChoiceFilter(
+        queryset=Tenant.objects.all(),
+        field_name='tenant__id',
+        to_field_name='id',
+        label='Tenant (id)',
+    )
+    tag = TagFilter()
+
+    class Meta():
+        model = Cluster
+        fields = ('cluster',)
+
+    def search(self, queryset, cluster, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(
+            Q(cluster__icontains=value)
+        )
+
+
+class DevicePoolFilterSet(BaseFilterSet):
+
+    q = django_filters.CharFilter(
+        method='search',
+        label='Search',
+    )
+    devicepool = django_filters.ModelMultipleChoiceFilter(
+        field_name='devicepool',
+        queryset=DevicePool.objects.all(),
+        to_field_name='devicepool',
+        label='devicepool',
+    )
+    tenant = django_filters.ModelMultipleChoiceFilter(
+        queryset=Tenant.objects.all(),
+        field_name='tenant__id',
+        to_field_name='id',
+        label='Tenant (id)',
+    )
+    region = django_filters.ModelMultipleChoiceFilter(
+        queryset=Region.objects.all(),
+        field_name='region__id',
+        to_field_name='id',
+        label='Region (id)',
+    )
+    tag = TagFilter()
+
+    class Meta():
+        model = DevicePool
+        fields = ('devicepool',)
+
+    def search(self, queryset, devicepool, value):
+        if not value.strip():
+            return queryset
+        return queryset.filter(
+            Q(devicepool__icontains=value)
+        )
