@@ -108,3 +108,69 @@ class Number(ChangeLoggedModel):
 
     class Meta:
         unique_together = ("number", "tenant",)#ermoe enant here
+
+
+class Cluster(ChangeLoggedModel):
+    cluster = models.CharField(max_length=200)
+    description = models.CharField(max_length=200)
+    tags = TaggableManager(through=TaggedItem)
+    tenant = models.ForeignKey(
+        to='tenancy.Tenant',
+        on_delete=models.CASCADE,
+        blank=False,
+        null=False
+    )
+    publisher = models.CharField(max_length=200)
+    subscriber1 = models.CharField(max_length=200)
+    subscriber2 = models.CharField(max_length=200)
+    subscriber3 = models.CharField(max_length=200)
+    subscriber4 = models.CharField(max_length=200)
+    tftp1 = models.CharField(max_length=200)
+    tftp2 = models.CharField(max_length=200)
+
+    objects = RestrictedQuerySet.as_manager()
+
+    csv_headers = ['cluster', 'tenant', 'description', 'publisher', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2']
+
+    def __str__(self):
+        return str(self.cluster)
+
+    def get_absolute_url(self):
+        return reverse("plugins:ucbox_plugin:cluster_view", kwargs={"pk": self.pk})
+
+    class Meta:
+        unique_together = ("cluster", "tenant",)#ermoe enant here
+
+
+
+class DevicePool(ChangeLoggedModel):
+    devicepool = models.CharField(max_length=200)
+    description = models.CharField(max_length=200)
+    tags = TaggableManager(through=TaggedItem)
+    tenant = models.ForeignKey(
+        to='tenancy.Tenant',
+        on_delete=models.CASCADE,
+        blank=False,
+        null=False
+    )
+    region = models.ForeignKey(
+        to="dcim.Region",
+        on_delete=models.SET_NULL,
+        blank=True,
+        null=True,
+        related_name="devicepool_region_set"
+    )
+    datetimegroup = models.CharField(max_length=200)
+    localroutegroup = models.CharField(max_length=200)
+    objects = RestrictedQuerySet.as_manager()
+
+    csv_headers = ['devicepool', 'tenant', 'description', 'region', 'datetimegroup', 'localroutegroup']
+
+    def __str__(self):
+        return str(self.devicepool)
+
+    def get_absolute_url(self):
+        return reverse("plugins:ucbox_plugin:devicepool_view", kwargs={"pk": self.pk})
+
+    class Meta:
+        unique_together = ("devicepool", "tenant",)#ermoe enant here
\ No newline at end of file
